@@ -58,13 +58,6 @@ struct _GstRTPRtxQueue
 
   guint max_size_time;
   guint max_size_packets;
-
-  GstSegment head_segment;
-  GstSegment tail_segment;
-
-  /* Statistics */
-  guint n_requests;
-  guint n_fulfilled_requests;
 };
 
 struct _GstRTPRtxQueueClass
@@ -72,9 +65,9 @@ struct _GstRTPRtxQueueClass
   GstElementClass parent_class;
 };
 
-GType gst_rtp_rtx_queue_get_type (void);
 
-GST_ELEMENT_REGISTER_DECLARE (rtprtxqueue);
+GType gst_rtp_rtx_queue_get_type (void);
+gboolean gst_rtp_rtx_queue_plugin_init (GstPlugin * plugin);
 
 G_END_DECLS
 #endif /* __GST_RTP_RTX_QUEUE_H__ */
